@@ -98,6 +98,7 @@ RDO_PKG_MAP = [
     SingleRule('distribute', 'python-setuptools'),
     SingleRule('dnspython', 'python-dns'),
     SingleRule('google-api-python-client', 'python-google-api-client'),
+    SingleRule('GitPython', 'GitPython'),
     SingleRule('pyOpenSSL', 'pyOpenSSL'),
     SingleRule('IPy', 'python-IPy'),
     SingleRule('pycrypto', 'python-crypto'),
@@ -123,6 +124,7 @@ RDO_PKG_MAP = [
     SingleRule('xattr', 'pyxattr'),
     SingleRule('XStatic-term.js', 'python-XStatic-termjs'),
     SingleRule('horizon', 'openstack-dashboard'),
+    SingleRule('networking-vsphere', 'openstack-neutron-vsphere'),
     MultiRule(
         mods=['PyYAML', 'm2crypto', 'numpy', 'pyflakes', 'pylint', 'pyparsing',
               'pystache', 'pytz', 'pysendfile', 'libvirt-python'],
@@ -186,10 +188,12 @@ SUSE_PKG_MAP = [
     SingleRule('magnum-ui', 'openstack-horizon-plugin-magnum-ui'),
     SingleRule('manila-ui', 'openstack-horizon-plugin-manila-ui'),
     SingleRule('monasca-ui', 'openstack-horizon-plugin-monasca-ui'),
+    SingleRule('murano-dashboard', 'openstack-horizon-plugin-murano-ui'),
     SingleRule('neutron-lbaas-dashboard',
                'openstack-horizon-plugin-neutron-lbaas-ui'),
     SingleRule('sahara-dashboard', 'openstack-horizon-plugin-sahara-ui'),
     SingleRule('trove-dashboard', 'openstack-horizon-plugin-trove-ui'),
+    SingleRule('networking-vsphere', 'openstack-neutron-vsphere'),
 ]
 
 UBUNTU_PKG_MAP = [
